# Dynamic U-Nets with PyTorch
> This package has some convenience functions for setting up U-Nets with pre-trained ResNets as the encoder.


## Install

`pip install dynamic_unet`

## Later
* Examples of how to use this package
* Add-ons for having arbitrary image classification networks being used as encoders, not just ResNets (which are limited to 3 channel inputs, and need some ad-hoc work to set up as encoders)

## Contact
dthiagarai@gmail.com
